{% extends "layout.html" %}
{% block body %}
<form action="{{ url_for('updateInstanceProfile') }}" method=post class=add-entry>
      <dl>
        <dt>Instance Profile:
        <dd><textarea name=content rows=20 cols=100>{{ profile }}</textarea>
        <dd><input type=submit value=Update>
      </dl>
    </form>
{% endblock %}

